==> metview_5.13.1.orig.tar.xz: metview-5.13.1/mir/src/mir/repres/regular/LambertAzimuthalEqualArea.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */


#pragma once

#include "mir/repres/regular/RegularGrid.h"
#include "mir/util/Types.h"


namespace mir {
namespace repres {
namespace regular {


class LambertAzimuthalEqualArea : public RegularGrid {
public:
    // -- Exceptions
    // None

    // -- Constructors

    LambertAzimuthalEqualArea(const param::MIRParametrisation&);
    LambertAzimuthalEqualArea(const LambertAzimuthalEqualArea&) = delete;
    LambertAzimuthalEqualArea& operator=(const LambertAzimuthalEqualArea&) = delete;

    // -- Destructor
    // None

    // -- Convertors
    // None

    // -- Operators
    // None

    // -- Methods
    // None

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

private:
    // -- Members
    // None

    // -- Methods

    static Projection make_projection(const param::MIRParametrisation&);

    // -- Overridden methods

    virtual void fill(grib_info&) const override;

    // -- Class members
    // None

    // -- Class methods
    // None

    // -- Friends
    // None
};


}  // namespace regular
}  // namespace repres
}  // namespace mir

==> metview_5.16.0.orig.tar.xz: metview-5.16.0/mir/src/mir/repres/regular/LambertAzimuthalEqualArea.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */


#pragma once

#include "mir/repres/regular/RegularGrid.h"


namespace mir {
namespace repres {
namespace regular {


class LambertAzimuthalEqualArea : public RegularGrid {
public:
    // -- Exceptions
    // None

    // -- Constructors

    LambertAzimuthalEqualArea(const param::MIRParametrisation&);
    LambertAzimuthalEqualArea(const Projection&, const util::BoundingBox&, const LinearSpacing& x,
                              const LinearSpacing& y, const util::Shape&);
    LambertAzimuthalEqualArea(const LambertAzimuthalEqualArea&) = delete;

    // -- Destructor
    // None

    // -- Convertors
    // None

    // -- Operators

    LambertAzimuthalEqualArea& operator=(const LambertAzimuthalEqualArea&) = delete;

    // -- Methods
    // None

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

private:
    // -- Members
    // None

    // -- Methods

    static Projection make_projection(const param::MIRParametrisation&);

    // -- Overridden methods

    void fill(grib_info&) const override;
    const Representation* croppedRepresentation(const util::BoundingBox&) const override;

    // -- Class members
    // None

    // -- Class methods
    // None

    // -- Friends
    // None
};


}  // namespace regular
}  // namespace repres
}  // namespace mir
